<?php

namespace App\Http\Controllers;

use App\Models\Restaurant;
use App\Models\Settings;
use Validator;
use Illuminate\Http\Request;

class RestaurantsController extends BaseController
{
    protected $base = 'restaurants';
    protected $cls = 'App\Models\Restaurant';
    protected $orderBy = 'sort';
    protected $orderByDir = 'ASC';
    protected $images = ['image'];
    protected $checkboxes = ['display_on_welcome_page'];
    protected $manyToMany = [
        'cuisines' => 'cuisines_ids'
    ];

    public function getValidator(Request $request)
    {
        $rules = [
            'name' => 'required',
            'sort' => 'required|integer'
        ];
        if (Settings::getSettings()->multiple_restaurants) {
            $rules['welcome_page_order'] = 'required|integer';
        }
        if (Settings::getSettings()->multiple_cities) {
            $rules['city_id'] = 'required';
        }
        return Validator::make($request->all(), $rules);
    }

    protected function getIndexItems($data)
    {
        if ($data != null) {
            $restaurants = Restaurant::policyScope();
            if (is_array($data) && isset($data['q'])) {
            	$restaurants = $restaurants->where('name', 'LIKE', '%' . $data['q'] . '%');
            }
            if (is_array($data) && isset($data['city_id'])) {
                $restaurants = $restaurants->where('city_id', $data['city_id']);
            }
            return $restaurants->paginate(20);
        }
        else {
            return Restaurant::policyScope()->paginate(20);
        }
    }
}
