<?php

namespace App\Policies;

use App\Models\User;
use App\Models\NewsItem;
use App\Models\Settings;
use Illuminate\Auth\Access\HandlesAuthorization;

class NewsItemPolicy
{
    use HandlesAuthorization;

    protected function canAccessCityId(User $user, NewsItem $newsItem)
    {
        $allow_cities = true;
        if (Settings::getSettings()->multiple_cities) {
            $allow_cities = in_array($newsItem->city_id, $user->cities->pluck('id')->all());
        }
        return $user->access_full || ($user->access_news && $allow_cities);
    }

    /**
     * Determine whether the user can view the newsItem.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\NewsItem  $newsItem
     * @return mixed
     */
    public function view(User $user, NewsItem $newsItem)
    {
        return $this->canAccessCityId($user, $newsItem);
    }

    /**
     * Determine whether the user can create taxGroups.
     *
     * @param  \App\Models\User  $user
     * @return mixed
     */
    public function create(User $user)
    {
        return ($user->access_full || $user->access_news);
    }

    /**
     * Determine whether the user can update the newsItem.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\NewsItem  $newsItem
     * @return mixed
     */
    public function update(User $user, NewsItem $newsItem)
    {
        return $this->canAccessCityId($user, $newsItem);
    }

    /**
     * Determine whether the user can delete the newsItem.
     *
     * @param  \App\Models\User  $user
     * @param  \App\Models\NewsItem  $newsItem
     * @return mixed
     */
    public function delete(User $user, NewsItem $newsItem)
    {
        return $this->canAccessCityId($user, $newsItem);
    }
}
