<x-app-layout>

<h4 class="c-grey-900 mT-10 mB-30">
    {{ __('messages.products.menu_title') }}
</h4>

<div class="bgc-white bd bdrs-3 p-20 mB-20">
    <form method="post" action="@if ($item->id == null) {{ route('products.store') }} @else {{ route('products.update', ['product' => $item->id]) }} @endif" enctype="multipart/form-data">
        {{ csrf_field() }}
        @if ($item->id != null)
            {{ method_field('PUT') }}
        @endif

        <div class="form-group {{ $errors->has('name') ? ' has-error' : '' }}">
            <label for="" class="control-label">{{__('messages.products.f_name')}}</label>
            <input type="text" class="form-control" value="{{$item->name}}" name="name"/>
            @if ($errors->has('name'))
                <span class="help-block">
                    <strong>{{ $errors->first('name') }}</strong>
                </span>
            @endif
        </div>

        <div class="form-group {{ $errors->has('sort') ? ' has-error' : '' }}">
            <label for="" class="control-label">{{__('messages.products.sort')}}</label>
            <input type="text" class="form-control" value="{{$item->sort}}" name="sort"/>
            @if ($errors->has('sort'))
                <span class="help-block">
                    <strong>{{ $errors->first('sort') }}</strong>
                </span>
            @endif
        </div>

        <div class="row">
            @if (\App\Models\Settings::getSettings()->multiple_cities)
                <div class="col-sm-6">
                    <div class="form-group">
                        <label for="" class="control-label">{{__('messages.products.f_city')}}</label>
                        <select name="city_id" class="form-control" id="cities">
                            <option value=""></option>
                            @foreach(\App\Models\City::policyScope()->get() as $city)
                                <option value="{{$city->id}}" @if ($item->city_id == $city->id) selected @endif>
                                    {{$city->name}}
                                </option>
                            @endforeach
                        </select>
                    </div>
                </div>
            @endif
            @if (\App\Models\Settings::getSettings()->multiple_restaurants)
                <div class="col-sm-6">
                    <div class="form-group">
                        <label for="" class="control-label">{{__('messages.products.f_restaurant')}}</label>
                        <select name="restaurant_id" class="form-control" id="restaurants">
                            <option value=""></option>
                            @foreach(\App\Models\Restaurant::policyScope()->get() as $restaurant)
                                <option data-city="{{ $restaurant->city_id }}" value="{{$restaurant->id}}" @if ($item->restaurant_id == $restaurant->id) selected @endif>
                                    {{$restaurant->name}}
                                </option>
                            @endforeach
                        </select>
                    </div>
                </div>
            @endif
        </div>

        <div class="form-group">
            <label for="" class="control-label">{{__('messages.products.f_category')}}</label>
            <select name="category_id" class="form-control" id="categories">
                <option value=""></option>
                @foreach($categories as $category)
                    <option data-city="{{ $category->city }}" data-restaurant="{{ $category->restaurant_id }}" value="{{$category->id}}" @if ($item->category_id == $category->id) selected @endif>
                        @for ($i = 0; $i < $category->depth; $i++) - @endfor {{$category->name}}
                    </option>
                @endforeach
            </select>
        </div>

        <div class="form-group">
            <label for="" class="control-label">{{__('messages.products.f_vendor')}}</label>
            <select name="vendor_id" class="form-control">
                <option value=""></option>
                @foreach(\App\Models\Vendor::all() as $vendor)
                    <option value="{{$vendor->id}}" @if ($item->vendor_id == $vendor->id) selected @endif>
                        {{$vendor->name}}
                    </option>
                @endforeach
            </select>
        </div>

        <div class="form-group">
            <label for="" class="control-label">{{__('messages.products.f_tax_group')}}</label>
            <select name="tax_group_id" class="form-control">
                <option value=""></option>
                @foreach(\App\Models\TaxGroup::all() as $tg)
                    <option value="{{$tg->id}}" @if ($item->tax_group_id == $tg->id) selected @endif>
                        {{$tg->name}}
                    </option>
                @endforeach
            </select>
        </div>

        <div class="row">
            <div class="col-sm-6">
                <div class="form-group {{ $errors->has('price') ? ' has-error' : '' }}">
                    <label for="" class="control-label">{{__('messages.products.f_price')}}</label>
                    <input type="text" class="form-control" value="{{$item->price}}" name="price"/>
                    @if ($errors->has('price'))
                        <span class="help-block">
                            <strong>{{ $errors->first('price') }}</strong>
                        </span>
                    @endif
                </div>
            </div>
            <div class="col-sm-6">
                <div class="form-group {{ $errors->has('price_old') ? ' has-error' : '' }}">
                    <label for="" class="control-label">{{__('messages.products.f_price_old')}}</label>
                    <input type="text" class="form-control" value="{{$item->price_old}}" name="price_old"/>
                    @if ($errors->has('price_old'))
                        <span class="help-block">
                            <strong>{{ $errors->first('price_old') }}</strong>
                        </span>
                    @endif
                </div>
            </div>
        </div>

        <div class="form-group">
            <label for="" class="control-label">{{__('messages.products.f_description')}}</label>
            <textarea name="description" class="form-control">{{ $item->description }}</textarea>
            @if ($errors->has('description'))
                <span class="help-block">
                    <strong>{{ $errors->first('description') }}</strong>
                </span>
            @endif
        </div>

        <h3>{{__('messages.products.f_image')}}</h3>
        <div class="row">
            @foreach($item->productImages as $image)
                <div class="col-sm-4 js-product-image-{{$image->id}}">
                    <div class="product-image-holder">
                        <a href="#" class="product-image-delete js-delete-product-image" data-id="{{$image->id}}">
                            <span class="ti-trash"></span>
                        </a>
                        <img src="{{$image->image}}" alt="" class="img-responsive">
                    </div>
                </div>
            @endforeach
        </div>
        <h4>{{__('messages.products.add_images')}}</h4>
        <div class="js-product-images-holder row">
            <div class="form-group js-product-image col-sm-4">
                <input type="file" name="image[]">
            </div>
        </div>
        <a href="#" class="js-add-image">
            <span class="glyphicon glyphicon-plus"></span>
            {{__('messages.products.add_image')}}
        </a>

        <br>
        <br>

        <h4>
			{{ __('messages.product_options.required_title') }}
            <a href="#" class="btn btn-xs btn-primary js-add-required">Add</a>
        </h4>
        <div class="row">
            <div class="col-sm-12">
                <div class="form-group {{ $errors->has('required_options_heading') ? ' has-error' : '' }}">
                    <label for="" class="control-label">{{ __('messages.product_options.required_heading') }}</label>
                    <input type="text" class="form-control" value="{{$item->required_options_heading}}" name="required_options_heading"/>
                    @if ($errors->has('required_options_heading'))
                        <span class="help-block">
                            <strong>{{ $errors->first('required_options_heading') }}</strong>
                        </span>
                    @endif
                </div>
            </div>
        </div>
        <div class="js-product-required-holder">
            <div class="row">
                <div class="col-5">
                    <label>{{ __('messages.product_options.name') }}</label>
                </div>
                <div class="col-3">
                    <label>{{ __('messages.product_options.price') }}</label>
                </div>
                <div class="col-3">
                    <label>{{ __('messages.product_options.sort') }}</label>
                </div>
                <div class="col-sm-1">
                </div>
            </div>
            @foreach ($item->requiredOptions as $option)
                @include('products.required', ['option' => $option])
            @endforeach
        </div>
        <br/>
        <br/>
        <br/>

        <h4>
			{{ __('messages.product_options.addons_title') }}
            <a href="#" class="btn btn-xs btn-primary js-add-option">Add</a>
        </h4>
        <div class="js-product-options-holder">
            <div class="row">
                <div class="col-5">
                    <label>{{ __('messages.product_options.name') }}</label>
                </div>
                <div class="col-3">
                    <label>{{ __('messages.product_options.price') }}</label>
                </div>
                <div class="col-3">
                    <label>{{ __('messages.product_options.sort') }}</label>
                </div>
                <div class="col-sm-1">
                </div>
            </div>
            @foreach ($item->productOptions as $option)
                @include('products.option', ['option' => $option])
            @endforeach
        </div>

        <button type="submit" class="btn btn-primary btn-block">{{__('messages.actions.save')}}</button>
    </form>

    <div class="js-product-required-template hidden">
        @include('products.required', ['option' => new \App\Models\RequiredOption()])
    </div>
    <div class="js-product-option-template hidden">
        @include('products.option', ['option' => new \App\Models\ProductOption()])
    </div>

    @if (\App\Models\Settings::getSettings()->multiple_cities || \App\Models\Settings::getSettings()->multiple_restaurants)
        <script src="/custom_js/products.js"></script>
    @endif
</div>

</x-app-layout>
